@@ -13,30 +13,36 @@ extern "C" {
  * https://xorshift.di.unimi.it/splitmix64.c
 */
 
-/* called from boot */
-void sm_srand(pUCXT) {
+void sm_srand(pUCXT, Pid_t pid) {
   unsigned int  n;
   UV            ptod[2];
 
-  /* gettimeofday(&tv, 0); */
-  (*UCXT.myU2time)(aTHX_ (UV*)&ptod);
-
   /*
-   * The idea is just to have a unique value here,
+   * The idea is to just have a unique value here,
    * so system time and process id should be enough.
    * (Provided system time doesn't repeat!)
    *
-   * Unix epoch time with usec resolution is 51 bits,
-   * leaving 13 bits for pid. We'll use the lower 13
-   * bits from getpid().
+   * But, since Unix epoch time with usec resolution
+   * is 51 bits, that only leaves 13 bits for pid.
+   *
+   * So, lets initially seed with TOD, mix, add the PID,
+   * then mix again.
   */
+
+  /* gettimeofday(&tv, 0); */
+  (*UCXT.myU2time)(aTHX_ (UV*)&ptod);
   UCXT.sm_x = (U64)ptod[0] * 1000000
-    + (U64)ptod[1]
-    + ((U64)getpid() << 51);
+    + (U64)ptod[1];
 
-  /* stir 8 - 39 times */
-  n = 8 + ((ptod[0] ^ ptod[1]) & 0x1f);
+  /* stir 16 - 31 times, pid-based */
+  n = 16 + (pid & 0x0f);
+  while (n-- > 0)
+    (void)sm_rand(aUCXT);
 
+  UCXT.sm_x ^= (U64)pid;
+
+  /* stir 16 - 31 times, time-based */
+  n = 16 + ((ptod[0] ^ ptod[1]) & 0x0f);
   while (n-- > 0)
     (void)sm_rand(aUCXT);
 }
